@@ -20,8 +20,8 @@ def napari_experimental_provide_function():
         subtract_background,
         threshold_otsu,
         binary_invert,
-        binary_watershed,
-        connected_components_labeling,
+        split_touching_objects,
+        connected_component_labeling,
         seeded_watershed,
         voronoi_otsu_labeling
     ]
@@ -44,7 +44,7 @@ def _sobel_3d(image):
     ])
     return ndi.convolve(image, kernel)
 
-def binary_watershed(binary:LabelsData, sigma:float=3.5) -> LabelsData:
+def split_touching_objects(binary:LabelsData, sigma:float=3.5) -> LabelsData:
     """
     Takes a binary image and draws cuts in the objects similar to the ImageJ watershed algorithm.
 
@@ -108,7 +108,7 @@ def binary_invert(binary_image:LabelsData) -> LabelsData:
     """
     return (np.asarray(binary_image) == 0) * 1
 
-def connected_components_labeling(binary_image:LabelsData) -> LabelsData:
+def connected_component_labeling(binary_image:LabelsData) -> LabelsData:
     """
     Takes a binary image and produces a label image with all separated objects labeled differently.
     """
